# -*- coding: utf-8 -*-
from mootdx.reader import Reader, ExReader
from mootdx.market import LiveReader, ExLiveReader

# reader = Reader(tdxdir='')
# reader.Daily(stock=None)
# reader.ExDaily(stock=None)
# reader.MinBar(stock=None)
# reader.Custom()
# reader.Block()



# -*- coding: utf-8 -*-
from pytdx.hq import TdxHq_API
from pytdx.exhq import TdxExHq_API

class LiveBars(object):
	"""docstring for LiveReader"""
	client = None

	def __init__(self, arg):
		super(LiveReader, self).__init__()
		self.client = TdxHq_API(auto_retry=True)
		self.client.connect()

	def __del__(self):
		self.client.disconnect()

	def bars(self, symbol=''):
		data = self.client.get_security_bars(9, 0, symbol, 0, 10)
		return self.client.to_df(data)

	def index(self, file='incon.dat'):
		pass

	def count(self):
		pass

	def symbol(self):
		pass

class ExLiveBars(LiveBars):
	"""docstring for ExLiveReader"""
	def __init__(self, arg):
		super(ExLiveBars, self).__init__()
		self.client = TdxExHq_API(auto_retry=True)
		self.client.connect()

	def bars(self, symbol=''):
		data = self.client.get_security_bars(9, 0, symbol, 0, 10)
		return self.client.to_df(data)
		


# -*- coding: utf-8 -*-
from pytdx.reader import (
	TdxFileNotFoundException,
	TdxExHqDailyBarReader, 
	CustomerBlockReader,
	TdxLCMinBarReader,
	TdxDailyBarReader, 
	TdxMinBarReader,
	BlockReader
)
import os

class Reader(object):
	"""docstring for Reader"""

	tdxdir = r'C:/new_tdx'

	def __init__(self, tdxdir=None):
		super(Reader, self).__init__()
		self.tdxdir = tdxdir

	def find_path(self, stock=None, subdir='lday', ext='day'):
		paths = [
			'vipdoc/sz/%s/sz%s.%s' % (subdir, stock, ext),
			'vipdoc/sh/%s/sh%s.%s' % (subdir, stock, ext),
		]
		
		for p in paths:
			path = os.path.join(self.tdxdir, p)
			if os.path.exists(path):
				return path

		return None

	def daily(self, stock=None):
		reader = TdxDailyBarReader()
		stocks = self.find_path(stock)
		return reader.get_df(stocks)

	def minbar(self, stock=None, subdir='minline'):
		stocks = self.find_path(stock, subdir='minline', ext='lc1')
		stocks = self.find_path(stock, subdir='minline', ext='1') if not stocks else stocks
		reader = TdxLCMinBarReader()
		return reader.get_df(stocks)

	def fzline(self, stock=None):
		stocks = self.find_path(stock, subdir='fzline', ext='lc5')
		stocks = self.find_path(stock, subdir='fzline', ext='5') if not stocks else stocks		
		reader = TdxLCMinBarReader()
		return reader.get_df(stocks)

	def block(self, group=False, custom=False):
		reader = BlockReader()
		stocks = os.path.join(self.tdxdir, 'block_zs.dat')
		return reader.get_df(stocks, True)
	
	def index(self, file='incon.dat'):
		reader = BlockReader()
		stocks = os.path.join(self.tdxdir, file)
		return reader.get_df(stocks, True)

class ExReader(Reader):
	"""docstring for ExReader"""

	def ExDaily(stock=None):
		reader = TdxExHqDailyBarReader()
		stocks = self.find_path(stock)
		return reader.get_df(stocks)

		